ps.plone.zmi
============

ZMI customizations for Plone instances.


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/ps.plone.zmi.png?branch=master
   :target: http://travis-ci.org/propertyshelf/ps.plone.zmi
